import subprocess
import os
from vkygpt.fngen import flnm

def write_code(code,prompt):
    # Specify the file name and code content
    file_name = flnm(prompt)
    code_content = code
    vscode_path = os.path.join(os.path.expanduser("~"), "AppData\Local\Programs\Microsoft VS Code\Code.exe")
    # Create or overwrite the Python file with the specified content
    with open(file_name, 'w') as file:
        file.write(code_content)
    try:
        subprocess.run([vscode_path, file_name], check=True)
    except subprocess.CalledProcessError as e:
        print(f"Error: {e}")


from requests import Session
from requests.exceptions import RequestException
from json import loads
from uuid import uuid4


class Completion:
    def create(self, prompt):
        headers = {
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.5112.79 Safari/537.36",
            "Referer": "https://gpt-gm.h2o.ai/",
        }

        with Session() as session:
            try:
                session.post(
                    "https://gpt-gm.h2o.ai/settings",
                    headers=headers,
                    data={
                        "ethicsModalAccepted": "true",
                        "shareConversationsWithModelAuthors": "false",
                        "ethicsModalAcceptedAt": "",
                        "activeModel": "h2oai/h2ogpt-gm-oasst1-en-2048-falcon-40b-v1",
                        "searchEnabled": "true",
                    },
                )
                resp = session.post(
                    "https://gpt-gm.h2o.ai/conversation",
                    headers=headers,
                    json={"model": "h2oai/h2ogpt-gm-oasst1-en-2048-falcon-40b-v1"},
                )
                resp_json = resp.json()
                resp = session.post(
                    f"https://gpt-gm.h2o.ai/conversation/{resp_json['conversationId']}",
                    headers={
                        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/115.0",
                    },
                    json={
                        "inputs": prompt,
                        "parameters": {
                            "temperature": 0.6,
                            "truncate": 2048,
                            "max_new_tokens": 2048,
                            "do_sample": True,
                            "repetition_penalty": 1.2,
                            "return_full_text": False,
                        },
                        "options": {
                            "id": str(uuid4()),
                            "response_id": str(uuid4()),
                            "is_retry": False,
                            "use_cache": False,
                            "web_search_id": "",
                        },
                    },
                )
                return loads(resp.text.replace("\n", "").split("data:")[-1])[
                    "generated_text"
                ]
            except RequestException as exc:
                raise RequestException("Unable to fetch the response.") from exc



from aiohttp import ClientSession, ClientError

class Completion:
    async def create(self, prompt):
        async with ClientSession() as session:
            try:
                async with session.post(
                    url="https://api.binjie.fun/api/generateStream",
                    headers={
                        "origin": "https://chat.jinshutuan.com",
                        "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.5112.79 Safari/537.36",
                    },
                    json={
                        "prompt": prompt,
                        "system": "Always talk in English.",
                        "withoutContext": True,
                        "stream": False,
                    },
                ) as resp:
                    return await resp.text()
            except ClientError as exc:
                raise ClientError("Unable to fetch the response.") from exc



from vkygpt import AsyncClient
from PIL import Image
from io import BytesIO
import os

async def imgen(prompt):
    print("🤖: Generating Image.....")
    try:
        resp = await AsyncClient.create_generation("prodia", prompt)
        generated_image = Image.open(BytesIO(resp))
        generated_image.show()
        save_image = input("Do you want to save the generated image? (yes/no): ").lower()

        if save_image == "yes" or save_image == 'y':
            downloads_folder = os.path.join(os.path.expanduser("~"), "Downloads")
            save_path = os.path.join(downloads_folder, "generated_image.png")
            generated_image.save(save_path)
            print(f"🤖: Image saved successfully at {save_path}")
        else:
            print("🤖: Image not saved.")

    except Exception as e:
        print(f"🤖: {e}")


from requests import post
from requests.exceptions import RequestException


class Completion:
    def create(self, prompt):
        try:
            resp = post(
                url="https://api.binjie.fun/api/generateStream",
                headers={
                    "origin": "https://chat.jinshutuan.com",
                    "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.5112.79 Safari/537.36",
                },
                json={
                    "prompt": prompt,
                    "withoutContext": True,
                    "stream": False,
                },
            )
            resp.encoding = "utf-8"
            return resp.text
        except RequestException as exc:
            raise RequestException("Unable to fetch the response.") from exc



from random import randint
from aiohttp import ClientSession, ClientError


class Generation:
    async def create(self, prompt):
        try:
            async with ClientSession() as session:
                async with session.get(
                    url=f"https://image.pollinations.ai/prompt/{prompt}{randint(1, 10000)}",
                    timeout=30,
                ) as resp:
                    return await resp.content.read()
        except ClientError as exc:
            raise ClientError("Unable to fetch the response.") from exc
